@@ -2,16 +2,20 @@ source(file.path(test_path(), "..", "helpers.R"))
 
 # ------------------------------------------------------------------------------
 
-test_that('formula interface', {
+test_that("formula interface", {
   skip_on_cran()
   expect_message(
-    expect_error({
-      set.seed(1)
-      res <- f_wflow %>%
-        tune_sim_anneal(cell_folds, iter = 2,
-                        control = control_sim_anneal(verbose = TRUE))
-    },
-    regex = NA)
+    expect_error(
+      {
+        set.seed(1)
+        res <- f_wflow %>%
+          tune_sim_anneal(cell_folds,
+            iter = 2,
+            control = control_sim_anneal(verbose = TRUE)
+          )
+      },
+      regex = NA
+    )
   )
   expect_equal(class(res), c("iteration_results", "tune_results", "tbl_df", "tbl", "data.frame"))
   expect_true(nrow(collect_metrics(res)) == 6)
@@ -19,16 +23,20 @@ test_that('formula interface', {
 
 # ------------------------------------------------------------------------------
 
-test_that('recipe interface', {
+test_that("recipe interface", {
   skip_on_cran()
   expect_silent(
-    expect_error({
-      set.seed(1)
-      res <- rec_wflow %>%
-        tune_sim_anneal(cell_folds, iter = 2,
-                        control = control_sim_anneal(verbose = FALSE))
-    },
-    regex = NA)
+    expect_error(
+      {
+        set.seed(1)
+        res <- rec_wflow %>%
+          tune_sim_anneal(cell_folds,
+            iter = 2,
+            control = control_sim_anneal(verbose = FALSE)
+          )
+      },
+      regex = NA
+    )
   )
   expect_equal(class(res), c("iteration_results", "tune_results", "tbl_df", "tbl", "data.frame"))
   expect_true(nrow(collect_metrics(res)) == 6)
@@ -36,16 +44,20 @@ test_that('recipe interface', {
 
 # ------------------------------------------------------------------------------
 
-test_that('variable interface', {
+test_that("variable interface", {
   skip_on_cran()
   expect_silent(
-    expect_error({
-      set.seed(1)
-      res <- var_wflow %>%
-        tune_sim_anneal(cell_folds, iter = 2,
-                        control = control_sim_anneal(verbose = FALSE))
-    },
-    regex = NA)
+    expect_error(
+      {
+        set.seed(1)
+        res <- var_wflow %>%
+          tune_sim_anneal(cell_folds,
+            iter = 2,
+            control = control_sim_anneal(verbose = FALSE)
+          )
+      },
+      regex = NA
+    )
   )
   expect_equal(class(res), c("iteration_results", "tune_results", "tbl_df", "tbl", "data.frame"))
   expect_true(nrow(collect_metrics(res)) == 6)
@@ -54,13 +66,17 @@ test_that('variable interface', {
   # as the initial object
 
   expect_silent(
-    expect_error({
-      set.seed(1)
-      new_res <- var_wflow %>%
-        tune_sim_anneal(cell_folds, iter = 2, initial = res,
-                        control = control_sim_anneal(verbose = FALSE))
-    },
-    regex = NA)
+    expect_error(
+      {
+        set.seed(1)
+        new_res <- var_wflow %>%
+          tune_sim_anneal(cell_folds,
+            iter = 2, initial = res,
+            control = control_sim_anneal(verbose = FALSE)
+          )
+      },
+      regex = NA
+    )
   )
   expect_true(nrow(collect_metrics(new_res)) == 10)
   expect_true(max(new_res$.iter) == 4)
@@ -72,18 +88,21 @@ test_that('variable interface', {
     tune_grid(cell_folds, grid = 2)
 
   expect_silent(
-    expect_error({
-      set.seed(1)
-      new_new_res <- var_wflow %>%
-        tune_sim_anneal(cell_folds, iter = 2, initial = grid_res,
-                        control = control_sim_anneal(verbose = FALSE))
-    },
-    regex = NA)
+    expect_error(
+      {
+        set.seed(1)
+        new_new_res <- var_wflow %>%
+          tune_sim_anneal(cell_folds,
+            iter = 2, initial = grid_res,
+            control = control_sim_anneal(verbose = FALSE)
+          )
+      },
+      regex = NA
+    )
   )
   expect_true(nrow(collect_metrics(new_new_res)) == 8)
   expect_true(max(new_new_res$.iter) == 2)
   expect_true(sum(grepl("^initial", collect_metrics(new_new_res)$.config)) == 4)
-
 })
 
 
@@ -115,11 +134,12 @@ test_that("unfinalized parameters", {
   rf_res <- wf_rf %>%
     tune_grid(resamples = bt, grid = 4)
 
-  expect_error({
-    set.seed(40)
-    rf_res_finetune <- wf_rf %>%
-      tune_sim_anneal(resamples = bt, initial = rf_res)
-  },
-  regex = NA
+  expect_error(
+    {
+      set.seed(40)
+      rf_res_finetune <- wf_rf %>%
+        tune_sim_anneal(resamples = bt, initial = rf_res)
+    },
+    regex = NA
   )
 })
